@@ -16,7 +16,9 @@ accept_header = "application/vnd.github.mercy-preview+json"
 
 def get_team(answers_github):
     target_team_name = answers_github.get("target_team_name")
-    team_url = f"https://api.github.com/orgs/nike-internal/teams/{target_team_name}"
+    source_org = answers_github.get("source_github_org")
+    target_org = answers_github.get("target_github_org")
+    team_url = f"https://api.github.com/orgs/{target_org}/teams/{target_team_name}"
     password = answers_github.get("github_password")
     team_resp = requests.get(team_url,
                              headers={"Authorization": "token " + password,
@@ -25,7 +27,7 @@ def get_team(answers_github):
     if team_resp.status_code == 200:
         team_id = json.loads(team_resp.content.decode()).get("id")
         team_ids.append(team_id)
-        if "parent" in json.loads(team_resp.content.decode()):
+        if "parent" in json.loads(team_resp.content.decode()) and json.loads(team_resp.content.decode())["parent"] is not None:
             parent_id = json.loads(team_resp.content.decode())["parent"]["id"]
             team_ids.append(parent_id)
 
@@ -37,18 +39,18 @@ def get_team(answers_github):
 
 
 def search_by_topic(topic, source_org, password, answers_github):
-    page = 1
-    count = 0
-
+    results = []
 
     url = f"https://api.github.com/search/repositories?q=org:{source_org} topic:{topic}"
 
     team_ids = get_team(answers_github)
 
+    headers = {"Authorization": "token " + password,
+               "Accept": "application/vnd.github.mercy-preview+json"}
+
     repo_response = requests.get(
         url,
-        headers={"Authorization": "token " + password,
-                 "Accept": "application/vnd.github.mercy-preview+json"})
+        headers=headers)
 
     repos_contents = repo_response.content.decode("utf-8")
 
@@ -56,7 +58,16 @@ def search_by_topic(topic, source_org, password, answers_github):
         content = json.loads(repos_contents)
         count = json.loads(repos_contents).get("total_count")
 
-        print("\n Found " + str(count) + " repos with topic " + topic + " in the org " + source_org)
+        results.extend(content.get("items"))
+
+        while "next" in repo_response.links:
+            url = repo_response.links["next"]["url"]
+            repo_response = requests.request("GET", url, headers=headers)
+            data = repo_response.json()
+            results.extend(data.get("items"))
+
+
+        print("\n Found " + str(len(results)) + " repos with topic " + topic + " in the org " + source_org)
         questions = [
             {
                 'type': 'confirm',
@@ -67,7 +78,7 @@ def search_by_topic(topic, source_org, password, answers_github):
         answers = prompt(questions, style=style)
 
         if answers.get('listRepos'):
-            for item in content.get("items"):
+            for item in results:
                 print(item.get("full_name"))
 
                 questions = [
@@ -80,11 +91,37 @@ def search_by_topic(topic, source_org, password, answers_github):
             proceed_answers = prompt(questions, style=style)
         else:
             proceed_answers = {"proceedToTransfer": True}
+
         if proceed_answers.get("proceedToTransfer"):
+            proceed_with_prompt = True
             for item in content.get("items"):
                 try:
+                    repo = item.get("name")
                     transfer_repo(item.get("name"), answers_github, team_ids)
                     print(f"Completed transfer for " + item.get("name"))
+                    if proceed_with_prompt:
+                        proceed = [
+                            {
+                                'type': 'list',
+                                'name': 'is_ok',
+                                'message': f"Check the  {repo} in target repo. Is it ok to proceed To next repo?",
+                                'choices': [
+                                    'yes',
+                                    'no',
+                                    "don't ask me again!"
+                                ]
+                            }
+                        ]
+
+                        proceed_answers_ok = prompt(questions=proceed, style=style)
+
+                        if proceed_answers_ok.get("is_ok") == "yes":
+                            continue
+                        elif proceed_answers_ok.get("is_ok") == "no":
+                            break
+                        elif proceed_answers_ok.get("is_ok") == "don't ask me again!":
+                            proceed_with_prompt = False
+
                 except Exception as ex:
                     print("Failed to transfer due to " + ex)
         else:
@@ -140,6 +177,9 @@ def transfer_repo(repo, answers, team_ids):
             else:
                 print("no webhooks found")
 
+        else:
+            print(f"Renaming {repo} failed due to error {str(rename_response.status_code)}")
+
         time.sleep(0.5)
 
         print("Renaming master to main")
@@ -149,9 +189,11 @@ def transfer_repo(repo, answers, team_ids):
 
         time.sleep(0.25)
         rename_response = requests.post(url=branch_url, headers=headers,
-                                         data=json.dumps(data))
+                                        data=json.dumps(data))
         if rename_response.status_code == 201:
             print("Renamed master to main")
+        else:
+            print(f"Renaming to master failed for repo {repo}")
 
 
 def migrate_github(answers, topic_answers):
